package cn.timer.api.dto.spmk;

import java.util.Date;
import java.util.List;

import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotBlank;

import cn.hutool.json.JSONObject;
import cn.timer.api.bean.spmk.SpmkInitiatorConfig;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class SpmkCustomApprovalDto {

	@ApiModelProperty(value = "编号 编号", example = "101")
	private Integer id;

	@ApiModelProperty(value = "企业组织代码 企业组织代码", example = "101")
	private Integer orgCode;

	@NotBlank(message = "approvalGId为空")
	@ApiModelProperty(value = "审批组id 当前用户ID", example = "101")
	private Integer approvalGId;

	@NotBlank(message = "iconUrl为空")
	@ApiModelProperty(value = "审批图标地址 ", example = "审批图标地址")
	private String iconUrl;

	@NotBlank(message = "name为空")
	@ApiModelProperty(value = "审批名称 ", example = "审批名称")
	private String name;

	@ApiModelProperty(value = "审批说明 ", example = "审批说明")
	private String description;

	@ApiModelProperty(value = "审批开关 0启用 1停用", example = "101")
	private Integer isOpen;

	@ApiModelProperty(value = "排序 排序", example = "101")
	private Integer ranks;

	@NotBlank(message = "isOpinion为空")
	@ApiModelProperty(value = "审批意见 是否必填 意见 0是 1否", example = "101")
	private Integer isOpinion;

	@ApiModelProperty(value = "更新时间 ", example = "更新时间")
	private Date updateTime;

	@ApiModelProperty(value = "创建时间 ", example = "创建时间")
	private Date createTime;

	@NotBlank(message = "assoType为空")
	@DecimalMax(value = "9",message = "assoType 只能为 0无 1转正 2离职 3调岗 4加班 5请假 6出差 7外出 8补卡 9调薪")
	@DecimalMin(value = "0",message = "assoType 只能为 0无 1转正 2离职 3调岗 4加班 5请假 6出差 7外出 8补卡 9调薪")
	@ApiModelProperty(value = "关联类型 0无 1转正 2离职 3调岗 4加班 5请假 6出差 7外出 8补卡 9调薪", example = "1")
	private Integer assoType;
	
	@NotBlank(message = "isAllvisible为空")
	@DecimalMax(value = "1",message = "isAllvisible 只能为 0否 1是")
	@DecimalMin(value = "0",message = "isAllvisible 只能为 0否 1是")
	@ApiModelProperty(value = "所有可见 0否 1是", example = "1")
	private Integer isAllvisible;

	@NotBlank(message = "froms为空")
	@ApiModelProperty(value = "审批表单 ", example = "审批表单")
	private List<JSONObject> froms;

	@NotBlank(message = "router为空")
	@ApiModelProperty(value = "审批流程 ", example = "审批流程")
	private Router router;

	@NotBlank(message = "initiatorConfigs为空")
	@ApiModelProperty(value = "可见发起人配置 ", example = "数组类型")
	private List<SpmkInitiatorConfig> initiatorConfigs;

}
